version 8.0
log using ch6_appendix.log, replace
#delimit ;


*************************************************************;
*     File-Name:  ch6_appendix.do                           *;
*     Date:       March 8, 2006                             *;
*     Author:     SNG                                       *;
*     Purpose: get results for threshold, over range of     *;
*              values for effective number of electoral     *;
*              parties. Same as Chapter 2 analysis.         *;
*     Input File: chapter6.dta                              *;
*     Output File: ch6_appendix.log                         *;
*     Machine: Dell                                         *;
*************************************************************;


use C:\data\chapter6.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;

generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);

replace asymmetry = 1-asymmetry if asymmetry<.5;

replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;

gen thresh_enep = threshold*enep;

*************************************************************;
*   Probit 2: Random effects probit, by election.           *;
*************************************************************;

xtprobit pec enep threshold thresh_enep, re i (ident);


preserve;
drawnorm SN_b1-SN_b5, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir
            using sim , replace;
            noisily display "start";

local a=0 ;
while `a' <= 10 { ;

quietly display "got here";
quietly {;


scalar h_threshold=8.59;
scalar h_enep=4.82;
scalar h_enep_thresh=h_enep*h_threshold;
scalar h_constant=1;

    generate x_betahat  = SN_b1*`a'
                            + SN_b2*h_threshold
                            + SN_b3*h_threshold*`a'
                            + SN_b4*h_constant;
    
    
    generate x_betahat1 =   SN_b1*(`a')
                            + SN_b2*(h_threshold+1)
                            + SN_b3*(h_threshold+1)*(`a')
                            + SN_b4*h_constant;
    
    
    gen prob =norm(x_betahat);
    gen prob1=norm(x_betahat1);
    gen diff=prob1-prob;
    gen risk=prob1/prob;
    
    egen probhat =mean(prob);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    egen relrisk=mean(risk);
    
    tempname prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir;  

    _pctile prob, p(2.5,97.5) ;
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `lod'= r(r1);
    scalar `hid'= r(r2);  

    _pctile risk, p(2.5,97.5);
    scalar `lor'= r(r1);
    scalar `hir'= r(r2);  
    
    scalar `prob_hat'=probhat;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    scalar `rel_risk'=relrisk;
    
    post mypost (`prob_hat') (`lo') (`hi') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`lod') (`hid') (`rel_risk') (`lor') (`hir') ;
    };      
    drop x_betahat x_betahat1 prob prob1 diff probhat probhat1 diffhat risk relrisk;
    local a=`a'+ .1 ;
    display "." _c;
} ;
display "";
postclose mypost;

use sim, clear;

gen parties = _n-1;


graph twoway line diff_hat parties, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line lod parties, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hid parties, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 10 20 30 40 50 60 70 80 90 100, labsize(3)) 
            ylabel(0 .005 .01, labsize(3))
            yscale(noline)
            xscale(noline)
            yline(0)
            yline(.005 .01, lcolor(white))
            legend(off)
            xtitle(Effective Electoral Parties, size(3.5)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of Threshold", size(3.5))
        scheme(s2mono) graphregion(fcolor(white));


translate @Graph c:\data\chap6_disproportionality.wmf, replace;


*************************************************************;
*  The marginal effct of disproportionality is positive and *;
*  significant when the effective number of parties is      *;
*  greater than 2.5 - this is obs 94-4460, or 98 percent    *;
*  of the sample.                                           *;
*************************************************************;

log close;
