version 8.0
log using chap6_appendix_substantive.log, replace
#delimit ;


*************************************************************;
*     File-Name:  chap6_appendix_substantive.do             *;
*     Date:       March 7, 2006                             *;
*     Author:     SNG                                       *;
*     Purpose: get substantive results for Ch6 appendix     *;
*     Input File: chapter6.dta                              *;
*     Output File: chap6_appendix_substantive.log           *;
*     Machine: Dell                                         *;
*************************************************************;

set mem 50m;

use C:\DATA\chapter6.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

generate seatshare = (seatlag1 + seatlag2)*100;
generate seatshare_2 = seatshare*seatshare;
gen polarization_threshold = polarization*threshold;
gen asymmetry = seatlag1 /(seatlag1 + seatlag2);
replace asymmetry = 1-asymmetry if asymmetry<.5;
replace asymmetry = 2*(asymmetry - .5);
gen asym_seat =  asymmetry*seatshare;
gen thresh_enep = threshold*enep;

sum enep;
sum threshold;

*************************************************************;
*           Random effects probit, by election.             *;
*************************************************************;

xtprobit pec enep threshold thresh_enep, re i (ident);


preserve;
drawnorm SN_b1-SN_b5, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;


scalar h_threshold=8.59;
scalar h_enep=4.82;
scalar h_constant=1;

    generate x_betahat  = SN_b1*h_enep
                            + SN_b2*h_threshold
                            + SN_b3*h_enep*h_threshold
                            + SN_b4*h_constant;
    
    
    generate x_betahat1 =   SN_b1*h_enep
                            + SN_b2*(h_threshold+9.68)
                            + SN_b3*h_enep*(h_threshold+9.68)
                            + SN_b4*h_constant;
    
    
    gen probhat =norm(x_betahat);
    gen probhat1=norm(x_betahat1);


*************************************************************;
* all variables held at their means - probhat               *;
* threshold 1 standard deviation higher - probhat1          *;
*************************************************************;

summarize probhat;
summarize probhat1;
centile probhat, centile(2.5 97.5);
centile probhat1, centile(2.5 97.5);
    gen diff=probhat1-probhat;
    sum diff;
centile diff, centile(2.5 97.5);
    gen risk=probhat1/probhat;
    sum risk;
centile risk, centile(2.5 97.5);



log close;
