version 8.0
log using chapter6.log, replace
#delimit ;


*************************************************************;
*     File-Name:  chapter6.do                               *;
*     Date:       April 24, 2005                            *;
*     Author:     SLN                                       *;
*     Purpose: get results for Chapter 6 (table of probit   *;
*              results and table of substantive results)    *;
*     Input File: chapter6.dta                              *;
*     Output File: chapter6.log                             *;
*     Machine: Compaq                                       *;
*************************************************************;

set mem 50m;

use C:\datasets\chapter6.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen seatshare = (seatlag1 + seatlag2)*100;
generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);
replace asymmetry = 1-asymmetry if asymmetry<.5;
replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;

sum seatshare incompatibility polarization threshold asymmetry;
sum pec if pec==1;

*************************************************************;
*    Probit 1: Basic probit with robust standard errors.    *;
*************************************************************;

probit pec incompatibility polarization threshold
           polarization_threshold seatshare seatshare_2
           asymmetry asym_seat, robust;


*************************************************************;
*   Probit 2: Random effects probit, by election.           *;
*************************************************************;

xtprobit pec incompatibility polarization threshold
             polarization_threshold seatshare seatshare_2
             asymmetry asym_seat, re i (ident);

*************************************************************;
*   Random effects probit, by election, IVs different order.*;
*************************************************************;

xtprobit pec seatshare seatshare_2 incompatibility polarization threshold
             polarization_threshold asymmetry asym_seat, re i (ident); 


preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;



scalar h_seatshare=31.37;
scalar h_seatshare_2=(h_seatshare*h_seatshare);
scalar h_incompatibility= 24.41;
scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_polarization_threshold=(h_polarization*h_threshold);
scalar h_asymmetry=.547;
scalar h_asym_seat=h_asymmetry*h_seatshare;
scalar h_constant=1;


*************************************************************;
* all variables held at their means - prob_hat1             *;
*************************************************************;

generate x_betahat1 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;

generate prob_hat1=norm(x_betahat1);

*************************************************************;
* incompatibility 1 standard deviation higher - prob_hat2   *;
*************************************************************;

generate x_betahat2 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*(h_incompatibility+20.31)
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat2=norm(x_betahat2);



*************************************************************;
*   Threshold at mean, polarization at min - prob_hat5      *;
*************************************************************;

generate x_betahat5 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*.09
                    + SN_b5*(h_threshold)
                    + SN_b6*(h_threshold)*(.09)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat5=norm(x_betahat5);

*************************************************************;
* Threshold +1 std dev., polarization at min - prob_hat6    *;
*************************************************************;

generate x_betahat6 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*.09
                    + SN_b5*(h_threshold+9.68)
                    + SN_b6*(h_threshold+9.68)*(.09)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat6=norm(x_betahat6);



*************************************************************;
*    Threshold at mean, polarization at max - prob_hat9     *;
*************************************************************;

generate x_betahat9 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*96.3
                    + SN_b5*(h_threshold)
                    + SN_b6*(96.3)*(h_threshold)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat9=norm(x_betahat9);

*************************************************************;
* Threshold +1 std dev., polarization at max - prob_hat10   *;
*************************************************************;

generate x_betahat10 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*96.3
                    + SN_b5*(h_threshold+9.68)
                    + SN_b6*(96.3)*(h_threshold+9.68)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat10=norm(x_betahat10);


*************************************************************;
*   polarization at mean, thresh = min, prob_hat13          *;
*************************************************************;

generate x_betahat13 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*(h_polarization)
                    + SN_b5*(.7)
                    + SN_b6*(h_polarization)*(.7)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;

generate prob_hat13=norm(x_betahat13);

*************************************************************;
*   polarization + 1 std.dev., thresh = min, prob_hat14     *;
*************************************************************;

generate x_betahat14 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*(h_polarization+19.38)
                    + SN_b5*(.7)
                    + SN_b6*(h_polarization+19.38)*(.7)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;

generate prob_hat14=norm(x_betahat14);


*************************************************************;
*   polarization at mean, thresh = max, prob_hat17          *;
*************************************************************;

generate x_betahat17 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*(h_polarization)
                    + SN_b5*(35)
                    + SN_b6*(h_polarization)*(35)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;

generate prob_hat17=norm(x_betahat17);


*************************************************************;
*   polarization + 1 std.dev., thresh = max, prob_hat18      *;
*************************************************************;

generate x_betahat18 = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*(h_polarization+19.38)
                    + SN_b5*(35)
                    + SN_b6*(h_polarization+19.38)*(35)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hat18=norm(x_betahat18);


*************************************************************;
* Asymmetry at mean, seatshare at min - prob_hat21          *;
*************************************************************;

generate x_betahat21 = SN_b1*0
                    + SN_b2*0
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asymmetry*0
                    + SN_b9*h_constant;

generate prob_hat21=norm(x_betahat21);

*************************************************************;
* Asymmetry +1 std dev., seatshare at min - prob_hat22      *;
*************************************************************;

generate x_betahat22 = SN_b1*0
                    + SN_b2*0
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*(h_asymmetry+.3103)
                    + SN_b8*(h_asymmetry+.3103)*0
                    + SN_b9*h_constant;

generate prob_hat22=norm(x_betahat22);


*************************************************************;
* Asymmetry at mean, seatshare at max - prob_hat25          *;
*************************************************************;

generate x_betahat25 = SN_b1*100
                    + SN_b2*100
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asymmetry*100
                    + SN_b9*h_constant;

generate prob_hat25=norm(x_betahat25);

*************************************************************;
* Asymmetry +1 std dev., seatshare at max - prob_hat26      *;
*************************************************************;

generate x_betahat26 = SN_b1*100
                    + SN_b2*100
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*h_threshold
                    + SN_b6*h_polarization_threshold
                    + SN_b7*(h_asymmetry+.3103)
                    + SN_b8*(h_asymmetry+.3103)*100
                    + SN_b9*h_constant;

generate prob_hat26=norm(x_betahat26);


*************************************************************;
* all variables held at their means - prob_hat1             *;
* incompatibility 1 standard deviation higher - prob_hat2   *;
*************************************************************;

summarize prob_hat1;
summarize prob_hat2;
centile prob_hat1, centile(2.5 97.5);
centile prob_hat2, centile(2.5 97.5);
    gen diff2=prob_hat2-prob_hat1;
    sum diff2;
centile diff2, centile(2.5 97.5);
    gen risk2=prob_hat2/prob_hat1;
    sum risk2;
centile risk2, centile(2.5 97.5);

*************************************************************;
* Threshold at mean, polarization at min - prob_hat5        *;
* Threshold +1 st dev, polarization at min - prob_hat6      *;
*************************************************************;

summarize prob_hat5;
summarize prob_hat6;
centile prob_hat5, centile(2.5 97.5);
centile prob_hat6, centile(2.5 97.5);
    gen diff6=prob_hat6-prob_hat5;
    sum diff6;
centile diff6, centile(2.5 97.5);
    gen risk6=(prob_hat6/prob_hat5);
    sum risk6;
centile risk6, centile(2.5 97.5);


*************************************************************;
* Threshold at mean, polarization at max - prob_hat9        *;
* Threshold +1 st dev, polarization at max - prob_hat10     *;
*************************************************************;

summarize prob_hat9;
summarize prob_hat10;
centile prob_hat9, centile(2.5 97.5);
centile prob_hat10, centile(2.5 97.5);
    gen diff10=prob_hat10-prob_hat9;
    sum diff10;
centile diff10, centile(2.5 97.5);
    gen risk10=(prob_hat10/prob_hat9);
    sum risk10;
centile risk10, centile(2.5 97.5);

*************************************************************;
* polarization at mean, thresh at min - prob_hat13          *;
* polarization + 1 std.dev., thresh at min - prob_hat14     *;
*************************************************************;

summarize prob_hat13;
summarize prob_hat14;
centile prob_hat13, centile(2.5 97.5);
centile prob_hat14, centile(2.5 97.5);
gen diff14=prob_hat14-prob_hat13;
sum diff14;
centile diff14, centile(2.5 97.5);
gen risk14=(prob_hat14/prob_hat13);
sum risk14;
centile risk14, centile(2.5 97.5);


*************************************************************;
* polarization at mean, thresh at max - prob_hat17          *;
* polarization + 1 std.dev., thresh at max - prob_hat18     *;
*************************************************************;

summarize prob_hat17;
summarize prob_hat18;
centile prob_hat17, centile(2.5 97.5);
centile prob_hat18, centile(2.5 97.5);
gen diff18=prob_hat18-prob_hat17;
sum diff18;
centile diff18, centile(2.5 97.5);
gen risk18=(prob_hat18/prob_hat17);
sum risk18;
centile risk18, centile(2.5 97.5);


*************************************************************;
* Asymmetry at mean, seatshare at min - prob_hat21          *;
* Asymmetry + 1 std.dev., seatshare at min - prob_hat22     *;
*************************************************************;

summarize prob_hat21;
summarize prob_hat22;
centile prob_hat21, centile(2.5 97.5);
centile prob_hat22, centile(2.5 97.5);
gen diff22=prob_hat22-prob_hat21;
sum diff22;
centile diff22, centile(2.5 97.5);
gen risk22=(prob_hat22/prob_hat21);
sum risk22;
centile risk22, centile(2.5 97.5);

*************************************************************;
* Asymmetry at mean, seatshare at max - prob_hat25          *;
* Asymmetry + 1 std.dev., seatshare at max - prob_hat26     *;
*************************************************************;

summarize prob_hat25;
summarize prob_hat26;
centile prob_hat25, centile(2.5 97.5);
centile prob_hat26, centile(2.5 97.5);
gen diff26=prob_hat26-prob_hat25;
sum diff26;
centile diff26, centile(2.5 97.5);
gen risk26=(prob_hat26/prob_hat25);
sum risk26;
centile risk26, centile(2.5 97.5);

*************************************************************;
*************************************************************;

log close;
