version 8.0
log using chapter6_extra.log, replace
#delimit ;


*************************************************************;
*     File-Name:  chapter6.do                               *;
*     Date:       April 24, 2005                            *;
*     Author:     SLN                                       *;
*     Purpose: get anecdotal results for Chapter 6          *;
*              results and table of substantive results)    *;
*     Input File: chapter6.dta                              *;
*     Output File: chapter6_extra.log                       *;
*     Machine: Compaq                                       *;
*************************************************************;

set mem 50m;

use C:\datasets\chapter6.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen seatshare = (seatlag1 + seatlag2)*100;
generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);
replace asymmetry = 1-asymmetry if asymmetry<.5;
replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;


*************************************************************;
*   Random effects probit, by election, IVs different order.*;
*************************************************************;

xtprobit pec seatshare seatshare_2 incompatibility polarization threshold
             polarization_threshold asymmetry asym_seat, re i (ident); 


preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;



scalar h_seatshare=31.37;
scalar h_seatshare_2=(h_seatshare*h_seatshare);
scalar h_incompatibility= 24.41;
scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_polarization_threshold=(h_polarization*h_threshold);
scalar h_asymmetry=.547;
scalar h_asym_seat=h_asymmetry*h_seatshare;
scalar h_constant=1;


*************************************************************;
*   all variables held at their means except threshold at   *;
*   2 percent (same as Denmark in the 1970s)                *;
*************************************************************;

generate x_betahatD = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*(2)
                    + SN_b6*h_polarization*(2)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;

generate prob_hatD=norm(x_betahatD);

*************************************************************;
*   Threshold moved to 8.9 percent (Norway in 1970s)        *;
*************************************************************;

generate x_betahatN = SN_b1*h_seatshare
                    + SN_b2*h_seatshare_2
                    + SN_b3*h_incompatibility
                    + SN_b4*h_polarization
                    + SN_b5*(8.9)
                    + SN_b6*h_polarization*(8.9)
                    + SN_b7*h_asymmetry
                    + SN_b8*h_asym_seat
                    + SN_b9*h_constant;


generate prob_hatN=norm(x_betahatN);


*************************************************************;
*   Threshold at 2 percent (Denmark example) - prob_hatD    *;
*   Threshold at 8.9 percent (Norway example) - prob_hatN   *;
*************************************************************;

summarize prob_hatD;
summarize prob_hatN;
centile prob_hatD, centile(2.5 97.5);
centile prob_hatN, centile(2.5 97.5);
    gen diffN=prob_hatN-prob_hatD;
    sum diffN;
centile diffN, centile(2.5 97.5);
    gen riskN=prob_hatN/prob_hatD;
    sum riskN;
centile riskN, centile(2.5 97.5);

*************************************************************;
*************************************************************;

log close;
